OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакты",
    "Address book name" : "Название адресной книги",
    "Import" : "Импорт",
    "The selected image is too big (max 1MB)" : "Выбранное изображение слишком велико (макс. 1 МБ)",
    "No contacts in here" : "Здесь нет контактов",
    "Name" : "Наименование контакта",
    "Organization" : "Организация",
    "Title" : "Должность",
    "Add field ..." : "Добавить поле ...",
    "+ New contact" : "+ Новый контакт",
    "No search result for {query}" : "По запросу {query} ничего не найдено",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакт","%n контакт","%n контактов"],
    "Post office box" : "Почтовый ящик",
    "Postal code" : "Почтовый индекс",
    "City" : "Город",
    "State or province" : "Область или район",
    "Country" : "Страна",
    "Address" : "Адрес",
    "(new group)" : "(новая группа)",
    "Last name" : "Фамилия",
    "First name" : "Имя",
    "Additional names" : "Отчество",
    "Prefix" : "Префикс",
    "Suffix" : "Суффикс",
    "All contacts" : "Все контакты",
    "Not grouped" : "Без группы",
    "New contact" : "Новый контакт",
    "{addressbook} shared by {owner}" : "{addressbook} поделился {owner}",
    "No contacts in file. Only VCard files are allowed." : "В файле нет контактов. Допустимы только файлы VCard.",
    "Nickname" : "Псевдоним",
    "Detailed name" : "Подробное имя",
    "Notes" : "Заметки",
    "Website" : "Сайт",
    "Federated Cloud ID" : "ID в объединении облачных хранилищ",
    "Home" : "Домашний",
    "Work" : "Рабочий",
    "Other" : "Другой",
    "Groups" : "Группы",
    "Birthday" : "День рождения",
    "Anniversary" : "Годовщина",
    "Date of death" : "Дата смерти",
    "Email" : "Эл. почта",
    "Instant messaging" : "Мессенджер",
    "Phone" : "Телефон",
    "Mobile" : "Мобильный",
    "Fax" : "Факс",
    "Fax home" : "Домашний факс",
    "Fax work" : "Факс работы",
    "Pager" : "Пейджер",
    "Voice" : "Голосовая почта",
    "Social network" : "Социальная сеть",
    "Settings" : "Настройки"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
